[![CircleCI](https://circleci.com/gh/AndreaCensi/reprep.svg?style=shield)](https://circleci.com/gh/AndreaCensi/reprep)


RepRep
======

A simple interface to create reports.


Install
-------


Demos
-----

Try:
    
    reprep_demos

And look in ``reprep_demos_out/index.html``.
